# OpenBB Wall St Journal Provider

This extension integrates the [WSJ](https://wsj.com/) data provider into the OpenBB Platform.

## Installation

To install the extension:

```bash
pip install openbb-wsj
```

For development please check [Contribution Guidelines](https://github.com/OpenBB-finance/OpenBBTerminal/blob/feature/openbb-sdk-v4/openbb_platform/CONTRIBUTING.md).

Documentation available [here](https://docs.openbb.co/sdk).
